from setuptools import setup
from keyring import get_keyring

setup(name='jaycob_probability',
      version='0.1',
      description='Gaussian distributions',
      packages=['jaycob_probability'],
      author = 'Jaycob Clavel',
      author_email = 'jaycobclavel101@gmail.com',
      zip_safe=False)
